@@ -1,6 +1,6 @@
 # ABSTRACT: 小说站点解析引擎
 package  Tiezi::Robot::Parser;
-our $VERSION = 0.10;
+our $VERSION = 0.11;
 
 sub new {
     my ( $self, %opt) = @_;
@@ -23,10 +23,10 @@ sub detect_site {
     return $site;
 } ## end sub detect_site
 
-sub calc_floor_wordnum {
+sub calc_content_wordnum {
     my ($self, $f) = @_;
-    return if(exists $f->{word_num});
-    my $wd = $f->{content};
+    return if($f->{word_num});
+    my $wd = $f->{content} || '';
     $wd =~ s/<[^>]+>//gs;
     $f->{word_num} = $wd =~ s/\S//gs;
     return $f;
